@@ -7,6 +7,7 @@
  * Contract with IBM Corp.
  ****************************************************************************** */
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
 
 import supertest from 'supertest';
 import nock from 'nock';
@@ -289,7 +290,7 @@ describe('Compliance Resolver', () => {
                   complianceName
                   complianceNamespace
                   valid
-                  enforcement
+                  remediation
                   status
                   raw
                   metadata {
@@ -454,7 +455,7 @@ describe('Compliance Resolver', () => {
                   complianceName
                   complianceNamespace
                   valid
-                  enforcement
+                  remediation
                   status
                   raw
                   metadata {
